@@ -22,13 +22,14 @@
 #include <string.h>
 #include <time.h>
 
-#include <QLayout>
 
 #include <KLocalizedString>
 #include <kdialog.h>
 
+#include <QBoxLayout>
+#include <QDebug>
+
 #include "ksmbstatus.h"
-#include "ksmbstatus.moc"
 
 #define Before(ttf,in) in.left(in.indexOf(ttf))
 #define After(ttf,in)  (in.contains(ttf)?QString(in.mid(in.indexOf(ttf)+QString(ttf).length())):QString(""))
@@ -55,7 +56,7 @@ NetMon::NetMon(QWidget * parent, KConfig *config) :
 
 	timer = new QTimer(this);
 	timer->start(15000);
-	QObject::connect(timer, SIGNAL(timeout()), this, SLOT(update()));
+	QObject::connect(timer, &QTimer::timeout, this, &NetMon::update);
 	update();
 }
 
@@ -124,7 +125,7 @@ void NetMon::readFromProcess() {
 	qint64 buflen = 8046; // 8k enough?
 	char buffer[buflen];
 	buflen = process->readLine(buffer, buflen);
-	//kDebug()<<"received stuff";
+	////qDebug()<<"received stuff";
 	char s[250], *start, *end;
 	size_t len;
 	start = buffer;
@@ -135,7 +136,7 @@ void NetMon::readFromProcess() {
 			len=sizeof(s)-1;
 		strncpy(s, start, len);
 		s[len] = '\0';
-		//kDebug() << "recived: "<<s;
+		////qDebug() << "recived: "<<s;
 		if (readingpart==nfs)
 			processNFSLine(s, len);
 		else
@@ -166,7 +167,7 @@ void NetMon::update() {
 	readingpart=header;
 	nrpid=0;
 	process->setEnvironment(QStringList() << ("PATH=" + path));
-	connect(process, SIGNAL(readyRead()), SLOT(readFromProcess()));
+	connect(process, &QProcess::readyRead, this, &NetMon::readFromProcess);
 	process->start("smbstatus");
 	if (!process->waitForFinished()) {
 		version->setText(i18n("Error run smbstatus: %1", process->errorString()));
@@ -191,14 +192,14 @@ void NetMon::update() {
 	readingpart=nfs;
 	delete showmountProc;
 	showmountProc=new QProcess();
-	connect(showmountProc, SIGNAL(readyRead()), SLOT(readFromProcess()));
+	connect(showmountProc, &QProcess::readyRead, this, &NetMon::readFromProcess);
 	showmountProc->setEnvironment(QStringList() << ("PATH=" + path));
 	//without this timer showmount hangs up to 5 minutes
 	//if the portmapper daemon isn't running
 	QTimer::singleShot(5000,this,SLOT(killShowmount()));
-	//kDebug()<<"starting kill timer with 5 seconds";
-	connect(showmountProc,SIGNAL(finished(int,QProcess::ExitStatus)),this,SLOT(killShowmount()));
-	connect(showmountProc,SIGNAL(error(QProcess::ProcessError)),this,SLOT(killShowmount()));
+	////qDebug()<<"starting kill timer with 5 seconds";
+	connect(showmountProc, static_cast<void (QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), this, &NetMon::killShowmount);
+	connect(showmountProc, static_cast<void (QProcess::*)(QProcess::ProcessError)>(&QProcess::error), this, &NetMon::killShowmount);
 	showmountProc->start("showmount", QStringList() << "-a" << "localhost");
 
 	version->adjustSize();
@@ -206,7 +207,7 @@ void NetMon::update() {
 }
 
 void NetMon::killShowmount() {
-	//kDebug()<<"killShowmount()";
+	////qDebug()<<"killShowmount()";
 	showmountProc->deleteLater();
 	showmountProc=0;
 }
